# Contributors

* Arnab Mondal [arnab.mondal@mila.quebec](mailto:arnab.mondal@mila.quebec)
* Arna Ghosh [arna.ghosh@mila.quebec](mailto:ghosharn@mila.quebec)
* Danielle Benesch [daniellerbenesch@gmail.com](mailto:daniellerbenesch@gmail.com)
